acfdist.ltraj and acfang.ltraj compute
(and by default plot) a correlogram-like function .acfdist.ltraj(x, which = c("dist", "dx", "dy"), nrep = 999, lag = 1,
plot = TRUE, xlab = "Lag", ylab = "autocorrelation")acfang.ltraj(x, which = c("absolute", "relative"), nrep = 999, lag = 1,
plot = TRUE, xlab = "Lag", ylab = "autocorrelation")
ltrajnrep permutations of values).acfdist.ltraj is used to compute a correlogram for
linear descriptors and acfang.ltraj for angular descriptors
(see as.ltraj for a description of these descriptors).Statistics used are defined in Dray et al. (in press). They are based on squared differences between successive values. For angular descriptors, the statistic is based on the chord distance.
In the case of missing data, the computation of the correlograms is restricted to the pairs of successive observed data and only observed data are permuted (i.e. the structure of the missing data is kept constant under permutation).
The grey area represents a 95 % interval obtained after permutation of the data. If the observed data is outside this region, it is considered as significant and represetend by a black symbol. Note that no multiple-comparison adjustement is performed.
as.ltraj for additional information on the class
ltraj, wawotest for a simple test of the
autocorrelation of the descriptive parameters on the trajectory.data(puechcirc)
puechcirc
acfang.ltraj(puechcirc, lag=5)
acfdist.ltraj(puechcirc, lag=5)Run the code above in your browser using DataLab