Learn R Programming

adehabitatLT (version 0.3.23)

na.omit.ltraj: Removes the missing values in a trajectory

Description

na.omit.ltraj can be used to remove missing relocations from a trajectory.

Usage

# S3 method for ltraj
na.omit(object, …)

Arguments

object

an object of class ltraj

additionnal arguments to be passed to or from other methods

Value

An object of class ltraj

See Also

setNA to place the missing values in the trajectory

Examples

Run this code
# NOT RUN {
data(puechcirc)
puechcirc

na.omit(puechcirc)

# }

Run the code above in your browser using DataLab