powered by
na.omit.ltraj can be used to remove missing relocations from a trajectory.
na.omit.ltraj
# S3 method for ltraj na.omit(object, …)
an object of class ltraj
ltraj
additionnal arguments to be passed to or from other methods
An object of class ltraj
setNA to place the missing values in the trajectory
setNA
# NOT RUN { data(puechcirc) puechcirc na.omit(puechcirc) # }
Run the code above in your browser using DataLab